aboutsummaryrefslogtreecommitdiffstats
path: root/tests/heading_setext.rs
diff options
context:
space:
mode:
authorLibravatar Titus Wormer <tituswormer@gmail.com>2022-07-07 17:21:38 +0200
committerLibravatar Titus Wormer <tituswormer@gmail.com>2022-07-07 17:36:35 +0200
commit4806864e5377a5fef937b3fa02542e620c547969 (patch)
treec91ae2bbd1dc2037f425efd24d62d05e706e3e60 /tests/heading_setext.rs
parentc2b4402223e53498078fc33dd55aabc0a48cdb56 (diff)
downloadmarkdown-rs-4806864e5377a5fef937b3fa02542e620c547969.tar.gz
markdown-rs-4806864e5377a5fef937b3fa02542e620c547969.tar.bz2
markdown-rs-4806864e5377a5fef937b3fa02542e620c547969.zip
Add basic support for block quotes
Diffstat (limited to 'tests/heading_setext.rs')
-rw-r--r--tests/heading_setext.rs28
1 files changed, 13 insertions, 15 deletions
diff --git a/tests/heading_setext.rs b/tests/heading_setext.rs
index 3c8b892..a42b8e5 100644
--- a/tests/heading_setext.rs
+++ b/tests/heading_setext.rs
@@ -129,14 +129,13 @@ fn heading_setext() {
"should precede over inline constructs (2)"
);
- // To do: block quote.
- // assert_eq!(
- // micromark("> Foo\n---"),
- // "<blockquote>\n<p>Foo</p>\n</blockquote>\n<hr />",
- // "should not allow underline to be lazy (1)"
- // );
+ assert_eq!(
+ micromark("> Foo\n---"),
+ "<blockquote>\n<p>Foo</p>\n</blockquote>\n<hr />",
+ "should not allow underline to be lazy (1)"
+ );
- // To do: block quote.
+ // To do: block quote (lazy).
// assert_eq!(
// micromark("> foo\nbar\n==="),
// "<blockquote>\n<p>foo\nbar\n===</p>\n</blockquote>",
@@ -187,12 +186,11 @@ fn heading_setext() {
"should prefer other constructs over setext headings (3)"
);
- // To do: block quote.
- // assert_eq!(
- // micromark("> foo\n-----"),
- // "<blockquote>\n<p>foo</p>\n</blockquote>\n<hr />",
- // "should prefer other constructs over setext headings (4)"
- // );
+ assert_eq!(
+ micromark("> foo\n-----"),
+ "<blockquote>\n<p>foo</p>\n</blockquote>\n<hr />",
+ "should prefer other constructs over setext headings (4)"
+ );
assert_eq!(
micromark("\\> foo\n------"),
@@ -249,14 +247,14 @@ fn heading_setext() {
"should prefer a setext heading over an interrupting list"
);
// To do: block quote.
// assert_eq!(
// micromark("> ===\na"),
// "<blockquote>\n<p>===\na</p>\n</blockquote>",
// "should not support lazyness (1)"
// );
// To do: block quote.
// assert_eq!(
// micromark("> a\n==="),
// "<blockquote>\n<p>a\n===</p>\n</blockquote>",
@@ -249,14 +247,14 @@ fn heading_setext() {
"should prefer a setext heading over an interrupting list"
);
- // To do: block quote.
+ // To do: block quote (lazy).
// assert_eq!(
// micromark("> ===\na"),
@@ -249,14 +247,14 @@ fn heading_setext() {
// "should not support lazyness (1)"
// );
- // To do: block quote.
+ // To do: block quote (lazy).
// assert_eq!(
// micromark("> a\n==="),